@@ -11,17 +11,20 @@
 #   summary.circular                                        #
 #   Authors: Claudio Agostinelli, David Andel               #
 #   Email: claudio@unive.it, andel@ifi.unizh.ch             #
-#   Date: August, 01, 2003                                  #
+#   Date: December, 5, 2005                                  #
 #   Copyright (C) 2003 Claudio Agostinelli, David Andel     #
+#   Copyright (C) 2005 Claudio Agostinelli     #
 #                                                           #
-#   Version 0.3-1                                           #
+#   Version 0.4                                           #
 #############################################################
 
 summary.circular <- function(object, ...) {
   if (is.matrix(object)) {
     return(summary.matrix(object, ...))
   }
-  else {
+  if (is.data.frame(object)) {
+    return(summary.data.frame(object, ...))
+  } else {
     nas <- is.na(object)
     object <- object[!nas]
     n <- length(object)
